==> nerualpha-4.0.1-py3-none-any.whl: nerualpha/providers/messages/contracts/sendImagePayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from nerualpha.providers.messages.contracts.ISendImagePayload import ISendImagePayload
from nerualpha.providers.messages.contracts.IMessageContact import IMessageContact
from nerualpha.providers.messages.contracts.sendImageContent import SendImageContent
from nerualpha.providers.messages.contracts.sendImageMessage import SendImageMessage

@dataclass
class SendImagePayload(ISendImagePayload):
    message: SendImageMessage
    to: IMessageContact
    from_: IMessageContact
    def __init__(self,from_,to,message):
        self.from_ = from_
        self.to = to
        if message.type_ is None:
            message.type_ = "image"
        
        self.message = SendImageMessage(message)
    
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result

==> nerualpha-5.0.1-py3-none-any.whl: nerualpha/providers/messages/contracts/sendImagePayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from nerualpha.providers.messages.contracts.ISendImagePayload import ISendImagePayload
from nerualpha.providers.messages.contracts.IMessageContact import IMessageContact
from nerualpha.providers.messages.contracts.sendImageContent import SendImageContent
from nerualpha.providers.messages.contracts.sendImageMessage import SendImageMessage

@dataclass
class SendImagePayload(ISendImagePayload):
    message: SendImageMessage
    to: IMessageContact
    from_: IMessageContact
    def __init__(self,from_: IMessageContact,to: IMessageContact,message: SendImageContent):
        self.from_ = from_
        self.to = to
        if message.type_ is None:
            message.type_ = "image"
        
        self.message = SendImageMessage(message)
    
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type", "return_":"return"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result
